==> yudit_1.1.orig.tar.gz: yudit-1.1/gui/lib/UTextFrame.h <==
//  UTextFrame.h version 1.1
//  yudit package - Unicode Editor for the X Window System (and Linux) 
//
//  Author: gsinai@iname.com (Gaspar Sinai)
//  GNU Copyright (C) 1997,1998  Gaspar Sinai
// 
//  yudit version 1.1  Copyright(C) 23 August,   1998, Tokyo Japan  Gaspar Sinai
//  yudit version 1.0  Copyright(C) 17 May,      1998, Tokyo Japan  Gaspar Sinai
//  yudit version 0.99 Copyright(C)  4 April,    1998, Tokyo Japan  Gaspar Sinai
//  yudit version 0.97 Copyright(C)  4 February, 1998, Tokyo Japan  Gaspar Sinai
//  yudit version 0.95 Copyright(C) 10 January,  1998, Tokyo Japan  Gaspar Sinai
//  yudit version 0.94 Copyright(C) 17 December, 1997, Tokyo Japan  Gaspar Sinai
//  yudit version 0.9 Copyright (C)  8 December, 1997, Tokyo Japan  Gaspar Sinai
//  yutex version 0.8 Copyright (C)  5 November, 1997, Tokyo Japan  Gaspar Sinai
//
//  This program is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 2 of the License, or
//  (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
//
#ifndef __utext_frame_h__
#define __utext_frame_h__

#include <UFrame.h>
#include <UScroll.h>
#include <UWidget.h>
#include "UUXKinput.h"

class UTextFrame : public UFrame , public UWidget
{
public:
				UTextFrame (UFrame* parent, int frameSize=2);
	virtual			~UTextFrame ();

	virtual void		eventDown (UEvent* event);

	virtual void 		setBackground (const UColor& color);
	virtual void 		setBackground (const char* color);
	virtual void 		setForeground (const UColor& color);
	virtual void 		setForeground (const char* color);
	virtual void		setFont (UFont* font);
	virtual int		isA (UComponent::UType type);
	virtual void		clearSelection ();
	virtual unsigned char*	uClipboardGet ();
	virtual void 		uClipboardPut (const unsigned char * text);

	virtual const UBestSize&	getBestSize(); 

	virtual void	resize (int width, int height);
	virtual void 	redraw (int x, int y, int width, int height);
	void		setFocus ();

	// overrridden
	void		uSetVScroll (int value, int step, int page, int max);
	void		uSetHScroll (int value, int step, int page, int max);
	int 		setXInput (const char* name, const char* imIn,
				const char* inputStyleIn, const char* textType,
				const char* uStringIn, const char* fontMap, 
				double versionIn=0.0);
private:
	UUXKinput*		xInput;
	UFontX11*		xInputFont;
	UFontMap*		xInputFontMap;
	void*			blinkTimer;
};


#endif /* __utext_frame_h__ */

==> yudit_1.5.orig.tar.gz: yudit-1.5/gui/lib/UTextFrame.h <==
//  UTextFrame.h version 1.5
//  yudit package - Unicode Editor for the X Window System (and Linux) 
//
//  Author: gsinai@iname.com (Gaspar Sinai)
//  GNU Copyright (C) 1997,1998,1999  Gaspar Sinai
// 
//  yudit version 1.5  Copyright(C) 30 November, 1999, Tokyo Japan  Gaspar Sinai
//  yudit version 1.4  Copyright(C) 25 November, 1999, Tokyo Japan  Gaspar Sinai
//  yudit version 1.3  Copyright(C)  5 April,    1999, Tokyo Japan  Gaspar Sinai
//  yudit version 1.2  Copyright(C) 10 December, 1998, Tokyo Japan  Gaspar Sinai
//  yudit version 1.1  Copyright(C) 23 August,   1998, Tokyo Japan  Gaspar Sinai
//  yudit version 1.0  Copyright(C) 17 May,      1998, Tokyo Japan  Gaspar Sinai
//  yudit version 0.99 Copyright(C)  4 April,    1998, Tokyo Japan  Gaspar Sinai
//  yudit version 0.97 Copyright(C)  4 February, 1998, Tokyo Japan  Gaspar Sinai
//  yudit version 0.95 Copyright(C) 10 January,  1998, Tokyo Japan  Gaspar Sinai
//  yudit version 0.94 Copyright(C) 17 December, 1997, Tokyo Japan  Gaspar Sinai
//  yudit version 0.9 Copyright (C)  8 December, 1997, Tokyo Japan  Gaspar Sinai
//  yutex version 0.8 Copyright (C)  5 November, 1997, Tokyo Japan  Gaspar Sinai
//
//  This program is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 2 of the License, or
//  (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
//
#ifndef __utext_frame_h__
#define __utext_frame_h__

#include <UFrame.h>
#include <UScroll.h>
#include <UWidget.h>
#include "UUXKinput.h"

class UTextFrame : public UFrame , public UWidget
{
public:
				UTextFrame (UFrame* parent, int frameSize=2);
	virtual			~UTextFrame ();

	virtual void		eventDown (UEvent* event);

	virtual void 		setBackground (const UColor& color);
	virtual void 		setBackground (const char* color);
	virtual void 		setForeground (const UColor& color);
	virtual void 		setForeground (const char* color);
	virtual void		setFont (UFont* font);
	virtual int		isA (UComponent::UType type);
	virtual void		clearSelection ();
	virtual unsigned char*	uClipboardGet (int* len);
	virtual void 		uClipboardPut (const unsigned char * text, const int len);

	virtual const UBestSize&	getBestSize(); 

	virtual void	resize (int width, int height);
	virtual void 	redraw (int x, int y, int width, int height);
	void		setFocus ();

	// overrridden
	void		uSetVScroll (int value, int step, int page, int max);
	void		uSetHScroll (int value, int step, int page, int max);
	int 		setXInput (const char* name, const char* imIn,
				const char* inputStyleIn, const char* textType,
				const char* uStringIn, const char* fontMap, 
				double versionIn=0.0);
private:
	UUXKinput*		xInput;
	UFontX11*		xInputFont;
	UFontMap*		xInputFontMap;
	void*			blinkTimer;
};


#endif /* __utext_frame_h__ */
